@@ -1,7 +1,7 @@
 package Getopt::Long::Complete;
 
 our $DATE = '2016-12-03'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -122,7 +122,7 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.29 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2016-12-03.
+This document describes version 0.30 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2016-12-03.
 
 =head1 SYNOPSIS
 
@@ -276,7 +276,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Lon
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Getopt-Long-Complete>.
+Source repository is at L<https://github.com/perlancar/perl-Getopt-Long-Complete>.
 
 =head1 BUGS
 
@@ -288,6 +288,10 @@ feature.
 
 =head1 SEE ALSO
 
+L<Getopt::Long::More>, another drop-in replacement for Getopt::Long with tab
+completion support and more stuffs: default value, required value, summary in
+auto_help.
+
 L<Complete::Getopt::Long> (the backend for this module), C<Complete::Bash>,
 C<Complete::Tcsh>.
 
